==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/Input/aac/translations/aac_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>AACMetaDataModel</name>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="43"/>
        <source>Length</source>
        <translation>אריכות</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="45"/>
        <source>Sample rate</source>
        <translation>שיעור דגימה</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="45"/>
        <source>Hz</source>
        <translation>הרץ</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="47"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="47"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="48"/>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="49"/>
        <source>File size</source>
        <translation>גודל קובץ</translation>
    </message>
</context>
<context>
    <name>DecoderAACFactory</name>
    <message>
        <location filename="../decoderaacfactory.cpp" line="46"/>
        <source>AAC Plugin</source>
        <translation>תוסף AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="48"/>
        <source>AAC Files</source>
        <translation>קבצי AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="88"/>
        <source>About AAC Audio Plugin</source>
        <translation>אודות תוסף שמע AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="89"/>
        <source>Qmmp AAC Audio Plugin</source>
        <translation>תוסף שמע AAC של Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="90"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חובר על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/aac/translations/aac_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>AACMetaDataModel</name>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="43"/>
        <source>Length</source>
        <translation>אריכות</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="45"/>
        <source>Sample rate</source>
        <translation>שיעור דגימה</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="45"/>
        <source>Hz</source>
        <translation>הרץ</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="47"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="47"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="48"/>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="49"/>
        <source>File size</source>
        <translation>גודל קובץ</translation>
    </message>
</context>
<context>
    <name>DecoderAACFactory</name>
    <message>
        <location filename="../decoderaacfactory.cpp" line="41"/>
        <source>AAC Plugin</source>
        <translation>תוסף AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="43"/>
        <source>AAC Files</source>
        <translation>קבצי AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="83"/>
        <source>About AAC Audio Plugin</source>
        <translation>אודות תוסף שמע AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="84"/>
        <source>Qmmp AAC Audio Plugin</source>
        <translation>תוסף שמע AAC של Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="85"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
